from __future__ import absolute_import, unicode_literals, print_function

_UNSET = object()

try:
    # python 3
    from configparser import ConfigParser, NoSectionError, NoOptionError
except ImportError:
    # python 2
    from ConfigParser import SafeConfigParser, NoSectionError, NoOptionError

    class ConfigParser(SafeConfigParser, object):
        def get(self, *args, **kwargs):
            fallback = kwargs.pop('fallback', _UNSET)
            try:
                return super(ConfigParser, self).get(*args, **kwargs)
            except (NoSectionError, NoOptionError) as e:
                if fallback is not _UNSET:
                    return fallback
                raise e

        def getboolean(self, *args, **kwargs):
            fallback = kwargs.pop('fallback', _UNSET)
            try:
                return super(ConfigParser, self).getboolean(*args, **kwargs)
            except (NoSectionError, NoOptionError) as e:
                if fallback is not _UNSET:
                    return fallback
                raise e

        def getint(self, *args, **kwargs):
            fallback = kwargs.pop('fallback', _UNSET)
            try:
                return super(ConfigParser, self).getint(*args, **kwargs)
            except (NoSectionError, NoOptionError) as e:
                if fallback is not _UNSET:
                    return fallback
                raise e


class ExtendedConfigParser(ConfigParser):
    def getlist(self, section, option, vars=None, fallback=_UNSET):
        try:
            s = self.get(section, option, vars=vars)
        except (NoSectionError, NoOptionError) as e:
            if fallback is not _UNSET:
                return fallback
            raise e

        if '\n' in s:
            sep = '\n'
        else:
            sep = ','

        items = []
        for item in s.split(sep):
            item = item.rstrip(',').strip().rstrip(',')
            if not item:
                continue
            items.append(item)
        return items
