#!/bin/bash

PROJECT_NAME="config_installer"

BUILD_TOOLS="curl build-essential fakeroot devscripts python-dev python-pip python3-pip"
BUILD_DEPENDS="debhelper dh-python python-all python-setuptools python-docutils python-sphinx python3-all python3-setuptools python3-docutils python3-sphinx"

BUILD_OUTPUT_COLOR="\033[0;36m"  # Cyan


set -e

_echo() {
    echo -e "${BUILD_OUTPUT_COLOR}${1}\033[0m"
}


# virtualenv
if [[ "${VIRTUAL_ENV:-}" ]]; then
    if ! deactivate 2>/dev/null; then
        echo -e "\033[0;31mERROR:\033[0m Please deactivate the virtualenv first!"
        exit 1
    fi
fi

###############################################################################
# clean

cleanup() {
    _echo "Cleaning up build files ..."
    rm setup.py || true
    rm -r ${PROJECT_NAME} || true
    rm test_requirements.txt || true
    rm MANIFEST.in || true
    rm README.* || true

    rm -r ${PROJECT_NAME}.egg-info/  || true
    rm -r __pycache__ || true
}
cleanup


###############################################################################
# install dependencies

apt-get update

_echo "Installing build tools ..."
apt-get install ${BUILD_TOOLS}

_echo "Installing Build-Depends ..."
apt-get install ${BUILD_DEPENDS}


###############################################################################
# collect sources

_echo "Copying sources ..."
cp -R ../../${PROJECT_NAME} ./
cp ../../setup.py ./
# cp ../../test_requirements.txt ./
cp ../../MANIFEST.in ./
cp ../../README.* ./

#_echo "Installing python packages for tests ..."
## The python-magic package in debian is the wrong one!
## For now we need to install it from pip.
#if hash pip; then
#    pip install -r test_requirements.txt
#    pip install mock
#fi
#if hash pip3; then
#    pip3 install -r test_requirements.txt
#fi


#echo "refresh debian/watch from pypi ..."
##curl -o debian/watch http://pypi.debian.net/${PROJECT_NAME}/watch


###############################################################################
# build

echo
_echo "Changelog:"
echo
FIRST_LINE=true
while IFS= read line; do
    if [[ "$line" =~ ^[\ ] ]] || [[ "$line" = "" ]] || [[ "${FIRST_LINE}" = true ]]; then
        _echo "  $line"  # or whaterver you want to do with the $line variable
        FIRST_LINE=false
    else
        break
    fi
done <debian/changelog
echo


export PROJECT_VERSION="$(python setup.py --version)"
_echo "Building ${PROJECT_NAME} ${PROJECT_VERSION}"


if [[ "${DEBIAN_FRONTEND}" != "noninteractive" ]]; then
    echo -e "Press ${BUILD_OUTPUT_COLOR}Enter\033[0m to continue ..."
    read -t 5
fi


_echo "Running dpkg-buildpackage ..."
dpkg-buildpackage -rfakeroot -us -uc -F

cleanup

_echo "build complete."
