#! /usr/bin/env python
"""
Test suite runner

Copyright (C) 2016-2018 Mathias Stelzer

config-installer is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

config-installer is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
from __future__ import absolute_import, print_function, unicode_literals

import os
import unittest
import shutil
import sys

from blessings import Terminal
from colour_runner.result import ColourTextTestResult, text_type
from unittest import TextTestRunner

try:
    import urllib.request
except ImportError:
    import urllib2

    def download(url, filename):
        response = urllib2.urlopen(url)
        with open(filename, 'wb') as out_file:
            shutil.copyfileobj(response, out_file)
else:
    def download(url, filename):
        with urllib.request.urlopen(url) as response, open(filename, 'wb') as out_file:
            shutil.copyfileobj(response, out_file)


__dirname__ = os.path.abspath(os.path.dirname(__file__))


class MyColourTextTestResult(ColourTextTestResult):
    _terminal = Terminal(force_styling=True)
    colours = {
        None: text_type,
        'error': _terminal.red,
        'expected': _terminal.blue,
        'fail': _terminal.yellow,
        'skip': text_type,
        'success': _terminal.green,
        'title': _terminal.cyan,
        'unexpected': _terminal.red,
    }


class ColourTextTestRunner(TextTestRunner):
    resultclass = MyColourTextTestResult


def main():
    suite = unittest.TestLoader().discover(__dirname__)
    result = ColourTextTestRunner(verbosity=2).run(suite)
    if not result.wasSuccessful():
        sys.exit(1)


if __name__ == '__main__':
    main()

